/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.equipmentOnlineRateAssessment.modular.monitorCamera.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.equipmentOnlineRateAssessment.modular.monitorCamera.entity.MonitorCamera;
import com.unis.equipmentOnlineRateAssessment.modular.monitorCamera.param.MonitorCameraAddParam;
import com.unis.equipmentOnlineRateAssessment.modular.monitorCamera.param.MonitorCameraEditParam;
import com.unis.equipmentOnlineRateAssessment.modular.monitorCamera.param.MonitorCameraIdParam;
import com.unis.equipmentOnlineRateAssessment.modular.monitorCamera.param.MonitorCameraPageParam;
import com.unis.equipmentOnlineRateAssessment.modular.monitorCamera.service.MonitorCameraService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 摄像头基本信息表控制器
 *
 * @author hjc
 * @date  2024/06/21 10:07
 */
@Api(tags = "摄像头基本信息表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class MonitorCameraController {

    @Resource
    private MonitorCameraService monitorCameraService;

    /**
     * 获取摄像头基本信息表分页
     *
     * @author hjc
     * @date  2024/06/21 10:07
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取摄像头基本信息表分页")
    //@SaCheckPermission("/equipmentOnlineRateAssessment/monitorCamera/page")
    @GetMapping("/equipmentOnlineRateAssessment/monitorCamera/page")
    public CommonResult<Page<MonitorCamera>> page(MonitorCameraPageParam monitorCameraPageParam) {
        return CommonResult.data(monitorCameraService.page(monitorCameraPageParam));
    }

    /**
     * 添加摄像头基本信息表
     *
     * @author hjc
     * @date  2024/06/21 10:07
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加摄像头基本信息表")
    @CommonLog("添加摄像头基本信息表")
    //@SaCheckPermission("/equipmentOnlineRateAssessment/monitorCamera/add")
    @PostMapping("/equipmentOnlineRateAssessment/monitorCamera/add")
    public CommonResult<String> add(@RequestBody @Valid MonitorCameraAddParam monitorCameraAddParam) {
        monitorCameraService.add(monitorCameraAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑摄像头基本信息表
     *
     * @author hjc
     * @date  2024/06/21 10:07
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑摄像头基本信息表")
    @CommonLog("编辑摄像头基本信息表")
    //@SaCheckPermission("/equipmentOnlineRateAssessment/monitorCamera/edit")
    @PostMapping("/equipmentOnlineRateAssessment/monitorCamera/edit")
    public CommonResult<String> edit(@RequestBody @Valid MonitorCameraEditParam monitorCameraEditParam) {
        monitorCameraService.edit(monitorCameraEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除摄像头基本信息表
     *
     * @author hjc
     * @date  2024/06/21 10:07
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除摄像头基本信息表")
    @CommonLog("删除摄像头基本信息表")
    //@SaCheckPermission("/equipmentOnlineRateAssessment/monitorCamera/delete")
    @PostMapping("/equipmentOnlineRateAssessment/monitorCamera/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<MonitorCameraIdParam> monitorCameraIdParamList) {
        monitorCameraService.delete(monitorCameraIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取摄像头基本信息表详情
     *
     * @author hjc
     * @date  2024/06/21 10:07
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取摄像头基本信息表详情")
    //@SaCheckPermission("/equipmentOnlineRateAssessment/monitorCamera/detail")
    @GetMapping("/equipmentOnlineRateAssessment/monitorCamera/detail")
    public CommonResult<MonitorCamera> detail(@Valid MonitorCameraIdParam monitorCameraIdParam) {
        return CommonResult.data(monitorCameraService.detail(monitorCameraIdParam));
    }
}
