/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.equipmentOnlineRateAssessment.modular.monitorCamera.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.equipmentOnlineRateAssessment.modular.monitorCamera.entity.MonitorCamera;
import com.unis.equipmentOnlineRateAssessment.modular.monitorCamera.mapper.MonitorCameraMapper;
import com.unis.equipmentOnlineRateAssessment.modular.monitorCamera.param.MonitorCameraAddParam;
import com.unis.equipmentOnlineRateAssessment.modular.monitorCamera.param.MonitorCameraEditParam;
import com.unis.equipmentOnlineRateAssessment.modular.monitorCamera.param.MonitorCameraIdParam;
import com.unis.equipmentOnlineRateAssessment.modular.monitorCamera.param.MonitorCameraPageParam;
import com.unis.equipmentOnlineRateAssessment.modular.monitorCamera.service.MonitorCameraService;

import java.util.List;

/**
 * 摄像头基本信息表Service接口实现类
 *
 * @author hjc
 * @date  2024/06/21 10:07
 **/
@Service
public class MonitorCameraServiceImpl extends ServiceImpl<MonitorCameraMapper, MonitorCamera> implements MonitorCameraService {

    @Override
    public Page<MonitorCamera> page(MonitorCameraPageParam monitorCameraPageParam) {
        QueryWrapper<MonitorCamera> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(monitorCameraPageParam.getSortField(), monitorCameraPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(monitorCameraPageParam.getSortOrder());
            queryWrapper.orderBy(true, monitorCameraPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(monitorCameraPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(MonitorCamera::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(MonitorCameraAddParam monitorCameraAddParam) {
        MonitorCamera monitorCamera = BeanUtil.toBean(monitorCameraAddParam, MonitorCamera.class);
        this.save(monitorCamera);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(MonitorCameraEditParam monitorCameraEditParam) {
        MonitorCamera monitorCamera = this.queryEntity(monitorCameraEditParam.getId());
        BeanUtil.copyProperties(monitorCameraEditParam, monitorCamera);
        this.updateById(monitorCamera);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<MonitorCameraIdParam> monitorCameraIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(monitorCameraIdParamList, MonitorCameraIdParam::getId));
    }

    @Override
    public MonitorCamera detail(MonitorCameraIdParam monitorCameraIdParam) {
        return this.queryEntity(monitorCameraIdParam.getId());
    }

    @Override
    public MonitorCamera queryEntity(Integer id) {
        MonitorCamera monitorCamera = this.getById(id);
        if(ObjectUtil.isEmpty(monitorCamera)) {
            throw new CommonException("摄像头基本信息表不存在，id值为：{}", id);
        }
        return monitorCamera;
    }
}
